@@ -512,11 +512,12 @@ setMethod("EBupdate","EBMTP",
               ### Begin nuts and bolts of EB here.
 t
               ### Set G function of type I error rates
-              error.closure <- switch(typeone, fwer=G.VS(V,S=NULL,tp=TRUE,bound=0),
-                                      gfwer=G.VS(V,S=NULL,tp=TRUE,bound=k),
-                                      tppfp=G.VS(V,S,tp=TRUE,bound=q),
-                                      fdr=G.VS(V,S,tp=FALSE,bound=NULL)
-                                      )
+              #REMOVED CLOSURE SO V,S DEFINED
+              #error.closure <- switch(typeone, fwer=G.VS(V,S=NULL,tp=TRUE,bound=0),
+              #                        gfwer=G.VS(V,S=NULL,tp=TRUE,bound=k),
+              #                        tppfp=G.VS(V,S,tp=TRUE,bound=q),
+              #                        fdr=G.VS(V,S,tp=FALSE,bound=NULL)
+              #                        )
 
               ### Generate guessed sets of true null hypotheses
               ### This function relates null and full densities.  Sidedness should be accounted for above.
@@ -560,7 +561,15 @@ t
                 Sn <- matrix(Sn, nr=clen, nc=B)
               }
 
-              G <-  error.closure(Vn,Sn)
+              ### Set G function of type I error rates
+              #REMOVED CLOSURE: G <-  error.closure(Vn,Sn)
+              
+              G <- switch(typeone, fwer=G.VS(Vn,Sn,tp=TRUE,bound=0),
+                         gfwer=G.VS(Vn,Sn,tp=TRUE,bound=k),
+                         tppfp=G.VS(Vn,Sn,tp=TRUE,bound=q),
+                         fdr=G.VS(Vn,Sn,tp=FALSE,bound=NULL)
+                )
+
               Gmeans <- rowSums(G,na.rm=TRUE)/B
 
               ### Now get adjps and rejection indicators.
